==> ejc-ztpcct-impl-3.0.0-20230921.055845-31-sources.jar: com/ejianc/ztpc/vo/GreatDangerProjectVO.java <==
package com.ejianc.ztpc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 危大工程
 * 
 * @author generator
 * 
 */
public class GreatDangerProjectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 编码
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 项目组织ID
    private String orgCode; // 项目组织编码
    private String orgName; // 项目组织名称
    private Long parentOrgId; // 父级组织ID
    private String parentOrgCode; // 父级组织编码
    private String parentOrgName; // 父级组织名称
    private Long consSchemeId; // 施工方案ID
    private String consSchemeName; // 施工方案名称
    private Long consSchemeType; // 施工方案类别--字典ct_cons_scheme_type
    private Long engineeringTypeId; // 工程类别
    private Long projectLeave; // 项目分级(自定义档案)
    private Date expertAtteDate; // 专家认证时间
    private Date disclosureDate; // 交底日期
    private Date acceptanceDate; // 验收日期
    private String examineSuper; // 检查监督
    private String implementation; // 实施情况
    private Date completeDate; // 完工日期
    private String remark; // 备注
    private Long expertArgumentFile; // 专项方案专家论证报告附件
    private Long technologyDisclosureFile; // 安全技术交底附件
    private Long disclosureUserFile; // 参与交底人员签名附件
    private Long userRegisterFile; // 作业人员登记表附件
    private Long userRecordFile; // 作业人员履历附件
    private Long examineAcceptanceFile; // 检查验收表附件
    private Long pollingRecordFile; // 巡检记录附件
    private Long substationRecordFile; // 监督旁站记录附件
    private String state; // 状态
    private String stateName; // 状态名称

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    @ReferSerialTransfer(referCode = "construction-scheme-ref")
    public Long getConsSchemeId() {
        return consSchemeId;
    }

    @ReferDeserialTransfer
    public void setConsSchemeId(Long consSchemeId) {
        this.consSchemeId = consSchemeId;
    }
    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getConsSchemeType() {
        return consSchemeType;
    }

    @ReferDeserialTransfer
    public void setConsSchemeType(Long consSchemeType) {
        this.consSchemeType = consSchemeType;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    @ReferDeserialTransfer
    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getProjectLeave() {
        return projectLeave;
    }

    @ReferDeserialTransfer
    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }
    public Date getExpertAtteDate() {
        return expertAtteDate;
    }

    public void setExpertAtteDate(Date expertAtteDate) {
        this.expertAtteDate = expertAtteDate;
    }
    public Date getDisclosureDate() {
        return disclosureDate;
    }

    public void setDisclosureDate(Date disclosureDate) {
        this.disclosureDate = disclosureDate;
    }
    public Date getAcceptanceDate() {
        return acceptanceDate;
    }

    public void setAcceptanceDate(Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    public String getExamineSuper() {
        return examineSuper;
    }

    public void setExamineSuper(String examineSuper) {
        this.examineSuper = examineSuper;
    }
    public String getImplementation() {
        return implementation;
    }

    public void setImplementation(String implementation) {
        this.implementation = implementation;
    }
    public Date getCompleteDate() {
        return completeDate;
    }

    public void setCompleteDate(Date completeDate) {
        this.completeDate = completeDate;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getExpertArgumentFile() {
        return expertArgumentFile;
    }

    public void setExpertArgumentFile(Long expertArgumentFile) {
        this.expertArgumentFile = expertArgumentFile;
    }
    public Long getTechnologyDisclosureFile() {
        return technologyDisclosureFile;
    }

    public void setTechnologyDisclosureFile(Long technologyDisclosureFile) {
        this.technologyDisclosureFile = technologyDisclosureFile;
    }
    public Long getDisclosureUserFile() {
        return disclosureUserFile;
    }

    public void setDisclosureUserFile(Long disclosureUserFile) {
        this.disclosureUserFile = disclosureUserFile;
    }
    public Long getUserRegisterFile() {
        return userRegisterFile;
    }

    public void setUserRegisterFile(Long userRegisterFile) {
        this.userRegisterFile = userRegisterFile;
    }
    public Long getUserRecordFile() {
        return userRecordFile;
    }

    public void setUserRecordFile(Long userRecordFile) {
        this.userRecordFile = userRecordFile;
    }
    public Long getExamineAcceptanceFile() {
        return examineAcceptanceFile;
    }

    public void setExamineAcceptanceFile(Long examineAcceptanceFile) {
        this.examineAcceptanceFile = examineAcceptanceFile;
    }
    public Long getPollingRecordFile() {
        return pollingRecordFile;
    }

    public void setPollingRecordFile(Long pollingRecordFile) {
        this.pollingRecordFile = pollingRecordFile;
    }
    public Long getSubstationRecordFile() {
        return substationRecordFile;
    }

    public void setSubstationRecordFile(Long substationRecordFile) {
        this.substationRecordFile = substationRecordFile;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getStateName() {
        return stateName;
    }

    public void setStateName(String stateName) {
        this.stateName = stateName;
    }
}

==> ejc-ztpcct-impl-3.0.0-20231008.063616-38-sources.jar: com/ejianc/ztpc/vo/GreatDangerProjectVO.java <==
package com.ejianc.ztpc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 危大工程
 * 
 * @author generator
 * 
 */
public class GreatDangerProjectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 编码
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 项目组织ID
    private String orgCode; // 项目组织编码
    private String orgName; // 项目组织名称
    private Long parentOrgId; // 父级组织ID
    private String parentOrgCode; // 父级组织编码
    private String parentOrgName; // 父级组织名称
    private Long consSchemeId; // 施工方案ID
    private String consSchemeName; // 施工方案名称
    private Long consSchemeType; // 施工方案类别--字典ct_cons_scheme_type
    private Long engineeringTypeId; // 工程类别
    private Long projectLeave; // 项目分级(自定义档案)
    private Date expertAtteDate; // 专家认证时间
    private Date disclosureDate; // 交底日期
    private Date acceptanceDate; // 验收日期
    private String examineSuper; // 检查监督
    private String implementation; // 实施情况
    private Date completeDate; // 完工日期
    private String remark; // 备注
    private Long expertArgumentFile; // 专项方案专家论证报告附件
    private Long technologyDisclosureFile; // 安全技术交底附件
    private Long disclosureUserFile; // 参与交底人员签名附件
    private Long userRegisterFile; // 作业人员登记表附件
    private Long userRecordFile; // 作业人员履历附件
    private Long examineAcceptanceFile; // 检查验收表附件
    private Long pollingRecordFile; // 巡检记录附件
    private Long substationRecordFile; // 监督旁站记录附件
    private String state; // 状态
    private String stateName; // 状态名称
    private Long constructionSchemeFile; // 施工方案附件
    private Long projectDisclosureFile; // 项目交底附件

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    @ReferSerialTransfer(referCode = "construction-scheme-ref")
    public Long getConsSchemeId() {
        return consSchemeId;
    }

    @ReferDeserialTransfer
    public void setConsSchemeId(Long consSchemeId) {
        this.consSchemeId = consSchemeId;
    }
    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getConsSchemeType() {
        return consSchemeType;
    }

    @ReferDeserialTransfer
    public void setConsSchemeType(Long consSchemeType) {
        this.consSchemeType = consSchemeType;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    @ReferDeserialTransfer
    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getProjectLeave() {
        return projectLeave;
    }

    @ReferDeserialTransfer
    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }
    public Date getExpertAtteDate() {
        return expertAtteDate;
    }

    public void setExpertAtteDate(Date expertAtteDate) {
        this.expertAtteDate = expertAtteDate;
    }
    public Date getDisclosureDate() {
        return disclosureDate;
    }

    public void setDisclosureDate(Date disclosureDate) {
        this.disclosureDate = disclosureDate;
    }
    public Date getAcceptanceDate() {
        return acceptanceDate;
    }

    public void setAcceptanceDate(Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    public String getExamineSuper() {
        return examineSuper;
    }

    public void setExamineSuper(String examineSuper) {
        this.examineSuper = examineSuper;
    }
    public String getImplementation() {
        return implementation;
    }

    public void setImplementation(String implementation) {
        this.implementation = implementation;
    }
    public Date getCompleteDate() {
        return completeDate;
    }

    public void setCompleteDate(Date completeDate) {
        this.completeDate = completeDate;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getExpertArgumentFile() {
        return expertArgumentFile;
    }

    public void setExpertArgumentFile(Long expertArgumentFile) {
        this.expertArgumentFile = expertArgumentFile;
    }
    public Long getTechnologyDisclosureFile() {
        return technologyDisclosureFile;
    }

    public void setTechnologyDisclosureFile(Long technologyDisclosureFile) {
        this.technologyDisclosureFile = technologyDisclosureFile;
    }
    public Long getDisclosureUserFile() {
        return disclosureUserFile;
    }

    public void setDisclosureUserFile(Long disclosureUserFile) {
        this.disclosureUserFile = disclosureUserFile;
    }
    public Long getUserRegisterFile() {
        return userRegisterFile;
    }

    public void setUserRegisterFile(Long userRegisterFile) {
        this.userRegisterFile = userRegisterFile;
    }
    public Long getUserRecordFile() {
        return userRecordFile;
    }

    public void setUserRecordFile(Long userRecordFile) {
        this.userRecordFile = userRecordFile;
    }
    public Long getExamineAcceptanceFile() {
        return examineAcceptanceFile;
    }

    public void setExamineAcceptanceFile(Long examineAcceptanceFile) {
        this.examineAcceptanceFile = examineAcceptanceFile;
    }
    public Long getPollingRecordFile() {
        return pollingRecordFile;
    }

    public void setPollingRecordFile(Long pollingRecordFile) {
        this.pollingRecordFile = pollingRecordFile;
    }
    public Long getSubstationRecordFile() {
        return substationRecordFile;
    }

    public void setSubstationRecordFile(Long substationRecordFile) {
        this.substationRecordFile = substationRecordFile;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getStateName() {
        return stateName;
    }

    public void setStateName(String stateName) {
        this.stateName = stateName;
    }

    public Long getConstructionSchemeFile() {
        return constructionSchemeFile;
    }

    public void setConstructionSchemeFile(Long constructionSchemeFile) {
        this.constructionSchemeFile = constructionSchemeFile;
    }

    public Long getProjectDisclosureFile() {
        return projectDisclosureFile;
    }

    public void setProjectDisclosureFile(Long projectDisclosureFile) {
        this.projectDisclosureFile = projectDisclosureFile;
    }
}
